@@ -22,6 +22,8 @@ if ($indent) {
         $css = CSS::Struct::Output::Raw->new(%params);
 }
 
+$css->put(['c', 'comment']);
+$css->put(['a', '@charset', 'utf-8']);
 $css->put(['s', 'selector#id']);
 $css->put(['s', 'div div']);
 $css->put(['s', '.class']);
@@ -37,9 +39,11 @@ print "\n";
 # Usage: __SCRIPT__ indent
 
 # Output with argument 0:
-# selector#id,div div,.class{weight:100px;font-size:10em;}
+# /*comment*/@charset "utf-8";selector#id,div div,.class{weight:100px;font-size:10em;}
 
+# /* comment */
 # Output with argument 1:
+# @charset "utf-8";
 # selector#id, div div, .class {
 #         weight: 100px;
 #         font-size: 10em;
