@@ -9,6 +9,8 @@ my $css = CSS::Struct::Output::Raw->new(
         'output_handler' => \*STDOUT,
 );
 
+$css->put(['c', 'comment']);
+$css->put(['a', '@charset', 'utf-8']);
 $css->put(['s', 'selector#id']);
 $css->put(['s', 'div div']);
 $css->put(['s', '.class']);
@@ -19,4 +21,4 @@ $css->put(['r', "\n"]);
 $css->flush;
 
 # Output:
-# selector#id,div div,.class{weight:100px;font-size:10em;}
\ No newline at end of file
+# /*comment*/@charset "utf-8";selector#id,div div,.class{weight:100px;font-size:10em;}
\ No newline at end of file
